searchData={"items":[{"type":"behaviour","title":"BroadwayCloudPubSub.Client","doc":"A generic behaviour to implement Pub/Sub Clients for `BroadwayCloudPubSub.Producer`.\n\nThis module defines callbacks to normalize options and receive messages\nfrom a Cloud Pub/Sub topic. Modules that implement this behaviour should be passed\nas the `:client` option from `BroadwayCloudPubSub.Producer`.","ref":"BroadwayCloudPubSub.Client.html"},{"type":"callback","title":"BroadwayCloudPubSub.Client.acknowledge/2","doc":"Dispatches an [`acknowledge`](https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.subscriptions/acknowledge) request.","ref":"BroadwayCloudPubSub.Client.html#c:acknowledge/2"},{"type":"callback","title":"BroadwayCloudPubSub.Client.init/1","doc":"","ref":"BroadwayCloudPubSub.Client.html#c:init/1"},{"type":"callback","title":"BroadwayCloudPubSub.Client.prepare_to_connect/2","doc":"Invoked once by BroadwayCloudPubSub.Producer during `Broadway.start_link/2`.\n\nThe goal of this task is to manipulate the producer options,\nif necessary at all, and introduce any new child specs that will be\nstarted in Broadway's supervision tree.","ref":"BroadwayCloudPubSub.Client.html#c:prepare_to_connect/2"},{"type":"callback","title":"BroadwayCloudPubSub.Client.put_deadline/3","doc":"Dispatches a [`modifyAckDeadline`](https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.subscriptions/modifyAckDeadline) request.","ref":"BroadwayCloudPubSub.Client.html#c:put_deadline/3"},{"type":"callback","title":"BroadwayCloudPubSub.Client.receive_messages/3","doc":"Dispatches a [`pull`](https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.subscriptions/pull) request.","ref":"BroadwayCloudPubSub.Client.html#c:receive_messages/3"},{"type":"type","title":"BroadwayCloudPubSub.Client.ack_deadline/0","doc":"The amount of time (in seconds) before Pub/Sub should reschedule a message.","ref":"BroadwayCloudPubSub.Client.html#t:ack_deadline/0"},{"type":"type","title":"BroadwayCloudPubSub.Client.ack_id/0","doc":"The `ackId` returned by Pub/Sub to be used when acknowledging a message.","ref":"BroadwayCloudPubSub.Client.html#t:ack_id/0"},{"type":"type","title":"BroadwayCloudPubSub.Client.ack_ids/0","doc":"A list of `ackId` strings.","ref":"BroadwayCloudPubSub.Client.html#t:ack_ids/0"},{"type":"type","title":"BroadwayCloudPubSub.Client.messages/0","doc":"A list of `Broadway.Message` structs.","ref":"BroadwayCloudPubSub.Client.html#t:messages/0"},{"type":"module","title":"BroadwayCloudPubSub.Producer","doc":"A GenStage producer that continuously receives messages from a Google Cloud Pub/Sub\ntopic and acknowledges them after being successfully processed.\n\nBy default this producer uses `BroadwayCloudPubSub.PullClient` to talk to Cloud\nPub/Sub, but you can provide your client by implementing the `BroadwayCloudPubSub.Client`\nbehaviour.\n\nFor a quick getting started on using Broadway with Cloud Pub/Sub, please see\nthe [Google Cloud Pub/Sub Guide](https://hexdocs.pm/broadway/google-cloud-pubsub.html).","ref":"BroadwayCloudPubSub.Producer.html"},{"type":"module","title":"Options - BroadwayCloudPubSub.Producer","doc":"Aside from `:receive_interval` and `:client` which are generic and apply to all\nproducers (regardless of the client implementation), all other options are specific to\n`BroadwayCloudPubSub.PullClient`, which is the default client.\n\n  * `:client` - A module that implements the BroadwayCloudPubSub.Client behaviour.\nThis module is responsible for fetching and acknowledging the messages.\nPay attention that all options passed to the producer will be forwarded\nto the client. It's up to the client to normalize the options it needs. The default value is `BroadwayCloudPubSub.PullClient`.\n\n  * `:subscription` - Required. The name of the subscription, including the project.\nFor example, if you project is named `\"my-project\"` and your\nsubscription is named `\"my-subscription\"`, then your subscription\nname is `\"projects/my-project/subscriptions/my-subscription\"`.\n\n  * `:max_number_of_messages` - The maximum number of messages to be fetched per request. The default value is `10`.\n\n  * `:on_failure` - Configures the acking behaviour for failed messages.\nSee the \"Acknowledgements\" section below for all the possible values.\nThis option can also be changed for each message through\n`Broadway.Message.configure_ack/2`. The default value is `:noop`.\n\n  * `:on_success` - Configures the acking behaviour for successful messages.\nSee the \"Acknowledgements\" section below for all the possible values.\nThis option can also be changed for each message through\n`Broadway.Message.configure_ack/2`. The default value is `:ack`.\n\n  * `:receive_interval` - The duration (in milliseconds) for which the producer waits\nbefore making a request for more messages. The default value is `5000`.\n\n  * `:receive_timeout` - The maximum time (in milliseconds) to wait for a response\nbefore the pull client returns an error. The default value is `:infinity`.\n\n  * `:goth` - The `Goth` module to use for authentication. Note that this option only applies to the\ndefault token generator.\n\n  * `:token_generator` - An MFArgs tuple that will be called before each request\nto fetch an authentication token. It should return `{:ok, String.t()} | {:error, any()}`.\nBy default this will invoke `Goth.fetch/1` with the `:goth` option.\nSee the \"Custom token generator\" section below for more information.\n\n  * `:base_url` - The base URL for the Cloud Pub/Sub service.\nThis option is mostly useful for testing via the Pub/Sub emulator. The default value is `\"https://pubsub.googleapis.com\"`.\n\n  * `:finch` - The name of the `Finch` pool. If no name is provided, then a default\npool will be started by the pipeline's supervisor. The default value is `nil`.","ref":"BroadwayCloudPubSub.Producer.html#module-options"},{"type":"module","title":"Custom token generator - BroadwayCloudPubSub.Producer","doc":"A custom token generator can be given as a MFArgs tuple.\n\nFor example, define a `MyApp.fetch_token/0` function:\n\n    defmodule MyApp do\n\n      @doc \"Fetches a Google auth token\"\n      def fetch_token do\n        with {:ok, token} <- Goth.fetch(MyApp.Goth)\n          {:ok, token.token}\n        end\n      end\n    end\n\nand configure the producer to use it:\n\n    token_generator: {MyApp, :fetch_token, []}","ref":"BroadwayCloudPubSub.Producer.html#module-custom-token-generator"},{"type":"module","title":"Acknowledgements - BroadwayCloudPubSub.Producer","doc":"You can use the `:on_success` and `:on_failure` options to control how\nmessages are acknowledged with the Pub/Sub system.\n\nBy default successful messages are acknowledged and failed messages are ignored.\nYou can set `:on_success` and `:on_failure` when starting this producer,\nor change them for each message through `Broadway.Message.configure_ack/2`.\n\nThe following values are supported by both `:on_success` and `:on_failure`:\n\n* `:ack` - Acknowledge the message. Pub/Sub can remove the message from\n   the subscription.\n\n* `:noop` - Do nothing. No requests will be made to Pub/Sub, and the\n   message will be rescheduled according to the subscription-level\n   `ackDeadlineSeconds`.\n\n* `:nack` - Make a request to Pub/Sub to set `ackDeadlineSeconds` to `0`,\n   which may cause the message to be immediately redelivered to another\n   connected consumer. Note that this does not modify the subscription-level\n   `ackDeadlineSeconds` used for subsequent messages.\n\n* `{:nack, integer}` - Modifies the `ackDeadlineSeconds` for a particular\n   message. Note that this does not modify the subscription-level\n   `ackDeadlineSeconds` used for subsequent messages.","ref":"BroadwayCloudPubSub.Producer.html#module-acknowledgements"},{"type":"module","title":"Batching - BroadwayCloudPubSub.Producer","doc":"Even if you are not interested in working with Broadway batches via the\n`handle_batch/3` callback, we recommend all Broadway pipelines with Pub/Sub\nproducers to define a default batcher with `batch_size` set to 10, so\nmessages can be acknowledged in batches, which improves the performance\nand reduces the cost of integrating with Google Cloud Pub/Sub. In addition,\nyou should ensure that `batch_timeout` is set to a value less than\nthe acknowledgement deadline on the subscription. Otherwise you could\npotentially have messages that remain in the subscription and are never\nacknowledged successfully.","ref":"BroadwayCloudPubSub.Producer.html#module-batching"},{"type":"module","title":"Example - BroadwayCloudPubSub.Producer","doc":"Broadway.start_link(MyBroadway,\n      name: MyBroadway,\n      producer: [\n        module: {BroadwayCloudPubSub.Producer,\n          goth: MyApp.Goth,\n          subscription: \"projects/my-project/subscriptions/my_subscription\"\n        }\n      ],\n      processors: [\n        default: []\n      ],\n      batchers: [\n        default: [\n          batch_size: 10,\n          batch_timeout: 2_000\n        ]\n      ]\n    )\n\nThe above configuration will set up a producer that continuously receives\nmessages from `\"projects/my-project/subscriptions/my_subscription\"` and sends\nthem downstream.","ref":"BroadwayCloudPubSub.Producer.html#module-example"},{"type":"module","title":"Telemetry - BroadwayCloudPubSub.Producer","doc":"This producer emits a few [Telemetry](https://github.com/beam-telemetry/telemetry)\nevents which are listed below.\n\n  * `[:broadway_cloud_pub_sub, :pull_client, :receive_messages, :start | :stop | :exception]` spans -\n    these events are emitted in \"span style\" when executing pull requests to GCP PubSub.\n    See `:telemetry.span/3`.\n\n    All these events have the measurements described in `:telemetry.span/3`. The events\n    contain the following metadata:\n\n    * `:max_messages` - the number of messages requested after applying the `max_messages`\n    config option to the existing demand\n    * `:demand` - the total demand accumulated into the producer\n    * `:name` - the name of the Broadway topology\n\n  * `[:broadway_cloud_pub_sub, :pull_client, :ack, :start | :stop | :exception]` span - these events\n    are emitted in \"span style\" when acking messages on GCP PubSub. See `:telemetry.span/3`.\n\n    All these events have the measurements described in `:telemetry.span/3`. The events\n    contain the following metadata:\n\n    * `:name` - the name of the Broadway topology","ref":"BroadwayCloudPubSub.Producer.html#module-telemetry"},{"type":"module","title":"BroadwayCloudPubSub.PullClient","doc":"A subscriptions [pull client](https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.subscriptions/pull) built on `Finch`.","ref":"BroadwayCloudPubSub.PullClient.html"},{"type":"extras","title":"BroadwayCloudPubSub","doc":"# BroadwayCloudPubSub\n\n[![CI](https://github.com/dashbitco/broadway_cloud_pub_sub/actions/workflows/ci.yml/badge.svg)](https://github.com/dashbitco/broadway_cloud_pub_sub/actions/workflows/ci.yml)\n\nA Google Cloud Pub/Sub connector for [Broadway](https://github.com/dashbitco/broadway).\n\nDocumentation can be found at [https://hexdocs.pm/broadway_cloud_pub_sub](https://hexdocs.pm/broadway_cloud_pub_sub).\n\nThis project provides:\n\n* `BroadwayCloudPubSub.Producer` - A GenStage producer that continuously receives messages from a Pub/Sub subscription acknowledges them after being successfully processed.\n* `BroadwayCloudPubSub.Client` - A generic behaviour to implement Pub/Sub clients.\n* `BroadwayCloudPubSub.PullClient` - Default REST client used by `BroadwayCloudPubSub.Producer`.","ref":"readme.html"},{"type":"extras","title":"Installation - BroadwayCloudPubSub","doc":"Add `:broadway_cloud_pub_sub` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:broadway_cloud_pub_sub, \"~> 0.9.0\"},\n    {:goth, \"~> 1.3\"}\n  ]\nend\n```\n\n> Note the [goth](https://hexdocs.pm/goth) package, which handles Google Authentication, is required for the default token generator.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - BroadwayCloudPubSub","doc":"Configure Broadway with one or more producers using `BroadwayCloudPubSub.Producer`:\n\n```elixir\nBroadway.start_link(MyBroadway,\n  name: MyBroadway,\n  producer: [\n    module: {BroadwayCloudPubSub.Producer,\n      goth: MyGoth,\n      subscription: \"projects/my-project/subscriptions/my-subscription\"\n    }\n  ]\n)\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - BroadwayCloudPubSub","doc":"Copyright 2019 Michael Crumm \\\nCopyright 2020 Dashbit\n\n  Licensed under the Apache License, Version 2.0 (the \"License\");\n  you may not use this file except in compliance with the License.\n  You may obtain a copy of the License at\n\n  http://www.apache.org/licenses/LICENSE-2.0\n\n  Unless required by applicable law or agreed to in writing, software\n  distributed under the License is distributed on an \"AS IS\" BASIS,\n  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  See the License for the specific language governing permissions and\n  limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.9.1] - 2024-06-21","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Forward compatibility with Broadway v1.1\n\n- Handle messages without data\n\n## [0.9.0] - 2023-11-06","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Requires Elixir v1.11+.\n\n- Relax `nimble_options` dependency.\n\n- Optional dependency `goth` must be v1.3+.\n\n- **Possible breaking change:** The default token generator requires the `:goth` option to fetch tokens.\n\n  If you had not yet upgraded to Goth v1.3+ please follow the [upgrade guide][goth_upgrade].\n  Then wherever you invoke `Broadway.start_link/2`, add the `:goth` option:\n\n  ```elixir\n  producer: [\n    module:\n      {BroadwayCloudPubSub.Producer,\n       goth: MyApp.Goth,\n       subscription: \"projects/ /subscriptions/ \"}\n  ]\n  ```\n\n  If you had previously upgraded to Goth v1.3+ then wherever you invoke `Broadway.start_link/2`,\n  you may have something like the following:\n\n  ```elixir\n  producer: [\n    module:\n      {BroadwayCloudPubSub.Producer,\n       subscription: \"projects/ /subscriptions/ \",\n       token_generator: {MyApp, :fetch_token, []}}\n  ]\n  ```\n\n  ...where `MyApp.fetch_token/0` is similar to the following:\n\n  ```elixir\n  defmodule MyApp\n    def fetch_token do\n      with {:ok, token} <- Goth.fetch(MyApp.Goth) do\n        {:ok, token.token}\n      end\n    end\n  end\n  ```\n\n  You can remove your custom token generator function and replace your producer config with this:\n\n\n  ```elixir\n  producer: [\n    module:\n      {BroadwayCloudPubSub.Producer,\n       goth: MyApp.Goth,\n       subscription: \"projects/ /subscriptions/ \"}\n  ]\n  ```","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- The `:goth` option specifies the [Goth][goth] server for\n  the default token generator.","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- The `:scope` option has been removed. You may set custom scopes on your own [Goth][goth] server\n  via the `:source` option.\n\n  For example, if you want to use the scope `\"https://www.googleapis.com/auth/pubsub\"`, then\n  wherever you start Goth add the `:scopes` option to your authentication source:\n\n  ```elixir\n    # The `:metadata` source type retrieves credentials from Google metadata servers.\n    # Refer to the Goth documentation for more source options.\n    source = {:metadata, scopes: [\"https://www.googleapis.com/auth/pubsub\"]}\n\n    children = [\n      {Goth, name: MyApp.Goth, source: source}\n    ]\n  ```\n\n## [0.8.0] - 2022-10-26\n\nThis version moves Cloud PubSub from Tesla to Finch, so read the notes below and upgrade with care.","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- Use `:finch` as the HTTP client and provide a `:finch` producer option for a user-defined HTTP pool\n\n- Make HTTP requests in a separate process for cleaner shutdown\n\n- Support multiple topologies from the same Brodway module\n\n- Add telemetry events around HTTP requests\n\n- Add `:deliveryAttempt` field to metadata","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- The `:pool_size` option has been removed. Define your own [Finch][finch]\n  pool and use the `:finch` option instead.\n\n  For example, if your `:pool_size` was 10, then add Finch to your application\n  supervision tree (usually located in `lib/my_app/application.ex`):\n\n  ```elixir\n  children =\n    [\n      {Finch, name: MyFinch, pools: %{:default => [size: 10]}}\n    ]\n  ```\n\n  ...and wherever you invoke `Broadway.start_link/2`, replace this:\n\n  ```elixir\n  producer: [\n    module:\n      {BroadwayCloudPubSub.Producer,\n       subscription: \"projects/ /subscriptions/ \",\n       pool_size: 10}\n  ]\n  ```\n\n  ...with this:\n\n  ```elixir\n  producer: [\n    module:\n      {BroadwayCloudPubSub.Producer,\n       subscription: \"projects/ /subscriptions/ \",\n       finch: MyFinch}\n  ]\n  ```\n\n## [0.7.1] - 2022-05-09","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `:receive_timeout` option\n\n## [0.7.0] - 2021-08-30","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Require Broadway 1.0\n\n## [0.6.3] - 2021-07-19","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Remove sensitive details from error log messages","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- A new `:middleware` option to pass a list of custom Tesla middleware\n- Failures to ack are now automatically retried. Retries can be customised via the new `:retry` option\n\n## [0.6.2] - 2021-02-24","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Fixed a bug causing malformed acknowledgement requests (#54)\n\n## [0.6.1] - 2021-02-23","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Decreased maximum number of ackIds per request (#49)\n\n## [0.6.0] - 2020-02-18","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Support for passing a tuple for the `scope` option","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Require [Broadway v0.6.0](https://hexdocs.pm/broadway/0.6.0)\n\n## [0.5.0] - 2019-11-06","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Client options for connection pools (#37)\n\n- Support for configuring acknowledgement behavior (#36)","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Move acknowledger behaviour from `GoogleApiClient` into `ClientAcknowledger` (#39)\n\n## [0.4.0] - 2019-08-19","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Move to Plataformatec GitHub organization and become an official Broadway connector\n\n- Rename behaviour `RestClient` to `Client` (#23)\n\n- Use hackney as the default adapter (#20)\n\n- Require Broadway 0.4.x and (optionally) Goth 1.x (#26)\n\n- Replace `:token_module` option with `:token_generator` (#29)\n\n- Hide `handle_receive_messages` function that was accidentally made public\n\n## [0.3.0] - 2019-05-08","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- **BREAKING:** The PubsubMessage struct now gets unpacked into the `%Broadway.Message{}` received in your pipeline.  If you were using `message.data.data` before, you can now use `message.data`. Additional properties from the PubsubMessage can be found in the message metadata, for instance: `message.metadata.attributes` or `message.metadata.messageId`.\n- Requires `:broadway ~> 0.3.0`\n\n## [0.1.3] - 2019-05-06","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Fixed `BroadwayCloudPubSub.GoogleApiClient` attempting to send an empty acknowledge request.\n\n## [0.1.2] - 2019-04-11","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- MIX_ENV for publishing releases to Hex.\n\n## [0.1.1] - 2019-04-11","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- This `CHANGELOG` file to hopefully serve as an evolving example of a\n  standardized open source project `CHANGELOG`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Fixed CircleCI build for publishing docs to Hex.\n\n## [0.1.0] - 2019-04-10","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- `BroadwayCloudPubSub.Producer` - A GenStage producer that continuously receives messages from\n    a Pub/Sub subscription acknowledges them after being successfully processed.\n- `BroadwayCloudPubSub.RestClient` - A generic behaviour to implement Pub/Sub clients using the [REST API](https://cloud.google.com/pubsub/docs/reference/rest/).\n- `BroadwayCloudPubSub.GoogleApiClient` - Default REST client used by `BroadwayCloudPubSub.Producer`.\n- `BroadwayCloudPubSub.Token` - A generic behaviour to implement token authentication for Pub/Sub clients.\n- `BroadwayCloudPubSub.GothToken` - Default token provider used by `BroadwayCloudPubSub.Producer`.\n\n[Unreleased]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.9.0...HEAD\n[0.9.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.8.0...v0.9.0\n[0.8.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.7.1...v0.8.0\n[0.7.1]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.7.0...v0.7.1\n[0.7.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.6.2...v0.7.0\n[0.6.3]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.6.2...v0.6.3\n[0.6.2]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.6.1...v0.6.2\n[0.6.1]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.6.0...v0.6.1\n[0.6.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.5.0...v0.6.0\n[0.5.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.4.0...v0.5.0\n[0.4.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.3.0...v0.4.0\n[0.3.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.1.3...v0.3.0\n[0.1.3]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.1.2...v0.1.3\n[0.1.2]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.1.1...v0.1.2\n[0.1.1]: https://github.com/dashbitco/broadway_cloud_pub_sub/compare/v0.1.0...v0.1.1\n[0.1.0]: https://github.com/dashbitco/broadway_cloud_pub_sub/releases/tag/v0.1.0\n\n\n[finch]: https://hexdocs.pm/finch\n[goth]: https://hexdocs.pm/goth\n[goth_upgrade]: https://hexdocs.pm/goth/upgrade_guide.html","ref":"changelog.html#added"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]},"content_type":"text/markdown"}